@@ -474,6 +474,14 @@ public:
 		const char *list[MAX_LIBINPUT / 2];
 	}	libaudio_t;
 
+        typedef struct
+        {
+                const char *remote;
+                const char *userid;
+                const char *type;
+                const char *status;
+        }	regauth_t;
+
 	/**
 	 * The event data structure includes the event identifier and
 	 * any paramaters.  Additional information is attached both to
@@ -1612,6 +1620,15 @@ public:
 	 */
 	inline unsigned getAvail(void)
 		{return avail;}
+
+        /**
+         * Fill registration data.
+         *
+         * @return number of records filled.
+         * @param data array to fill.
+         * @param number of entries available.
+         */
+        virtual unsigned getRegistration(regauth_t *data, unsigned count);
 };	
 
 /**
