@@ -78,6 +78,11 @@ BayonneDriver::~BayonneDriver()
 	}
 }
 
+unsigned BayonneDriver::getRegistration(regauth_t *data, unsigned count)
+{
+        return 0;
+}
+
 void BayonneDriver::del(BayonneSession *session)
 {
 	BayonneDriver *driver = session->driver;
