@@ -50,6 +50,7 @@ class Session;
 class Registry : public ScriptRegistry
 {
 public:
+	Registry *next;
 	const char *uri, *contact, *proxy;
 	const char *iface;
 //	const char *route;
@@ -65,6 +66,7 @@ public:
 	bool active;
 
 	bool isActive(void);
+	void add(ScriptImage *img);
 };
 	
 class Driver : public BayonneDriver, public Audio, public Thread
@@ -110,6 +112,8 @@ public:
 
 	inline Level getSilence(void)
 		{return silence;};
+
+	unsigned getRegistration(regauth_t *data, unsigned count);
 };
 
 class RTPStream : public SymmetricRTPSession, public AudioBase, private TimerPort, private Mutex, public Bayonne
