@@ -30,6 +30,7 @@ TCPSession(server)
 void Session::startSelect(const char *name, const char *dial, const char *caller, const char *display)
 {
 	BayonneSpan *span;
+	BayonneDriver *trunk = BayonneDriver::getTrunking();
 	BayonneSession *session;
 	ScriptImage *img = useImage();
 	Name *scr = img->getScript(name);
@@ -47,9 +48,9 @@ void Session::startSelect(const char *name, const char *dial, const char *caller
 	if(!scr || !scr->select || scr->access != scrPUBLIC)
 	{
 		endImage(img);
-		if(Bayonne::start_driver && scr)
+		if(trunk && scr)
 		{
-			startDriver(start_driver, name, dial, caller, display);
+			startDriver(trunk, name, dial, caller, display);
 			return;
 		}
 		if(scr && !scr->select && scr->access == scrPUBLIC)
@@ -191,6 +192,7 @@ void Session::help(void)
 	*tcp() << "drivers [names..] - display loaded drivers" << endl;
 	*tcp() << "mon state|all timeslots.. - enable state monitoring" << endl;
 	*tcp() << "nomon timeslots.. - disable state monitoring" << endl;
+        *tcp() << "reg - display protocol registrations" << endl;
 	*tcp() << "reload - reload script configuration" << endl;
 	*tcp() << "shutdown - shutdown server" << endl;
 	*tcp() << "spans - list active spans in server" << endl;
@@ -200,6 +202,44 @@ void Session::help(void)
 	*tcp() << "uptime - show current server uptime" << endl;
 }
 
+void Session::reg(void)
+{
+	const char *proto;
+	regauth_t *data;
+	unsigned count, idx = 0;
+	char buf[80];
+	BayonneDriver *d = BayonneDriver::getPrimary();
+
+	if(!d)
+	{
+		*tcp() << "*** invalid driver or no protocols" << endl;
+		return;
+	}
+
+	data = new regauth_t[1024];
+	count = d->getRegistration(data, 1024);
+	if(!count)
+	{
+		*tcp() << "*** no active registrations" << endl;
+		return;
+	}
+
+	snprintf(buf, sizeof(buf), "%22s %16s %6s %8s",
+		"remote", "userid", "type", "status");
+	*tcp() << buf << endl;
+	while(idx < count)
+	{
+		snprintf(buf, sizeof(buf), "%22s %16s %6s %8s",
+			data[idx].remote, data[idx].userid,
+			data[idx].type, data[idx].status);
+		*tcp() << buf << endl;
+		++idx;
+	}
+
+	delete[] data;
+}
+
+
 void Session::uptime(void)
 {
 	unsigned long upt = Bayonne::uptime();
@@ -491,6 +531,10 @@ void Session::run(void)
 				login = false;
 				break;
 			}
+                        else if(!strnicmp(*argv, "reg", 3))
+                        {
+                                reg();
+                        }
 			else if(!strnicmp(*argv, "nomon", 5))
 			{
 				nomon(&argv[1]);
