@@ -34,7 +34,7 @@ bool Methods::scrTransfer(void)
 		svr = driver->getLast("outbound");
 
 	if(!svr)
-		svr = getSymbol("session.server");
+		svr = getSymbol("session.uri_server");
 
 	if(!pre)
 		pre = driver->getLast("transfer");
@@ -55,16 +55,17 @@ bool Methods::scrTransfer(void)
 		if(strchr(nbuf, '@'))
 			svr = NULL;
 
+                len = strlen(pre);
+                if(svr && len && !strnicmp(pre, svr, len))
+                        svr += len;
+                else if(!svr && len && !strnicmp(pre, nbuf, len))
+                        pre = "";
+
 		if(svr)
 			snprintf(state.url.buf, sizeof(state.url.buf), "%s%s@%s", pre, nbuf, svr);
 		else
-			snprintf(state.url.buf, sizeof(state.url.buf), "%s", nbuf);
+			snprintf(state.url.buf, sizeof(state.url.buf), "%s%s", pre, nbuf);
 
-		if(*pre && strnicmp(state.url.buf, pre, strlen(pre)))
-		{
-			error("invalid-url");
-			return true;
-		}
 		state.url.ref = state.url.buf;
 		setState(STATE_XFER);
 		return false;
